# Lauft
Python command line tool to check website availability.

## Configuration
Configuration is loaded from `$HOME/.config/lauft/config.json`.

```json
{"services":[
  {"url": "https://example.com", "title":"Example Domain"},
  {"url": "https://example.org"}
]}
```

## Usage
Run `lauft` after installing it.